summaryrefslogtreecommitdiff
path: root/src/third_party/wiredtiger/test/cppsuite/src/main/test.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/third_party/wiredtiger/test/cppsuite/src/main/test.cpp')
-rw-r--r--src/third_party/wiredtiger/test/cppsuite/src/main/test.cpp5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/third_party/wiredtiger/test/cppsuite/src/main/test.cpp b/src/third_party/wiredtiger/test/cppsuite/src/main/test.cpp
index e00f676f17d..526486b9d1d 100644
--- a/src/third_party/wiredtiger/test/cppsuite/src/main/test.cpp
+++ b/src/third_party/wiredtiger/test/cppsuite/src/main/test.cpp
@@ -94,9 +94,8 @@ test::run()
bool enable_logging, statistics_logging;
configuration *statistics_config;
std::string statistics_type;
- /* Build the database creation config string. */
- std::string db_create_config = CONNECTION_CREATE;
-
+ /* Build the database creation config string. Allow for a maximum 1024 sessions. */
+ std::string db_create_config = CONNECTION_CREATE + ",session_max=1024";
/* Enable snappy compression or reverse collator if required. */
if (_config->get_bool(COMPRESSION_ENABLED) || _config->get_bool(REVERSE_COLLATOR)) {
db_create_config += ",extensions=[";